import java.awt.BorderLayout;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.UIManager;

import com.steema.teechart.TChart;
import com.steema.teechart.drawing.Color;
import com.steema.teechart.legend.LegendAlignment;
import com.steema.teechart.styles.Bar;
import com.steema.teechart.styles.Line;
import com.steema.teechart.themes.ThemesList;


final public class ChartClass extends JPanel {	
	/**
     * @param args
     *            the command line arguments
     */
    public static void main(String[] args) {

        javax.swing.SwingUtilities.invokeLater(new Runnable() {

            public void run() {
                try {
                    UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
                    // Calls the method where we create the Chart and add to the window
                    createAndShowChart();
                } catch (Exception ex) {
                    ex.printStackTrace();
                }
            }
        });
    }
    
    /** Creates a new instance of Main */
    public ChartClass() {
        super(new BorderLayout());
    }	    

    private static void createAndShowChart() {
    	TChart myChart;
    	
        JFrame.setDefaultLookAndFeelDecorated(true);
        JFrame window = new JFrame("TeeChart for Java");
        window.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);

        window.addWindowListener(new WindowAdapter() {

            public void windowClosing(WindowEvent we) {
                System.exit(0);
            }
        });

        myChart = new TChart();
        
        // Changing the Chart aspect        
        ThemesList.applyTheme(myChart.getChart(),1);
        myChart.getPanel().getGradient().setVisible(true);
        myChart.getPanel().getGradient().setStartColor(Color.fromArgb(255,5,150,203));
        myChart.getPanel().getGradient().setEndColor(Color.fromArgb(255,3,64,180));
        myChart.getLegend().setAlignment(LegendAlignment.BOTTOM);
        myChart.getWalls().setVisible(false);       
        
        // Adding series to the Chart
        Bar bar1 = new Bar();
        Line line1 = new Line();
        
        bar1.fillSampleValues(10);
        line1.fillSampleValues(10);
        
        // Changing the Series aspect
        bar1.setColorEach(true);
        bar1.getPen().setVisible(false);
        bar1.getMarks().getFont().setColor(Color.WHITE);
        bar1.getMarks().setTransparent(true);;
        
        line1.getLinePen().setVisible(false);
        line1.setSmoothed(true);
        
        myChart.addSeries(bar1);
        myChart.addSeries(line1);
             
        window.add(myChart, BorderLayout.CENTER);
        window.pack();

        window.setLocationRelativeTo(null);
        window.setVisible(true);
    }
}
